@@ -1,8 +1,5 @@
 package Time::ETA;
-{
-  $Time::ETA::VERSION = '1.1.1';
-}
-
+$Time::ETA::VERSION = '1.2.0';
 # ABSTRACT: calculate estimated time of accomplishment
 
 
@@ -56,6 +53,15 @@ sub get_elapsed_seconds {
 }
 
 
+sub get_elapsed_time {
+    my ($self) = @_;
+
+    my $time = $self->_get_time_from_seconds($self->get_elapsed_seconds());
+
+    return $time;
+}
+
+
 sub get_remaining_seconds {
     my ($self) = @_;
 
@@ -362,13 +368,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Time::ETA - calculate estimated time of accomplishment
 
 =head1 VERSION
 
-version 1.1.1
+version 1.2.0
 
 =head1 SYNOPSIS
 
@@ -448,6 +456,20 @@ second have passed from the moment the new() constructor has executed.
 If the process is finished this method will return process run time in
 seconds.
 
+=head2 get_elapsed_time
+
+B<Get:> 1) $self
+
+B<Return:> 1) $text_time - scalar with the text representation of elapsed
+time.
+
+Method return elapsed time in the form "H:MM:SS". For example it can return
+"11:54:12", it means that the process is running for 11 hours, 54 minutes and
+12 seconds.
+
+This method returns the same number as get_elapsed_seconds(), but in format
+that is easy for humans to understand.
+
 =head2 get_remaining_seconds
 
 B<Get:> 1) $self
@@ -631,7 +653,7 @@ serialized object data and creates an object.
 The $string is created by the method serialized().
 
 spawn() die if $string is incorrect. You can check if it is possible to
-respawn object from a $string with the method can_cpawn().
+respawn object from a $string with the method can_spawn().
 
 =head2 can_spawn
 
@@ -674,6 +696,8 @@ with code that is not build with Dist::Zilla.
 
 =item L<Time::Progress>
 
+=item L<http://blogs.perl.org/users/steven_haryanto/2014/02/getting-a-progress-report-from-a-running-program.html>
+
 =back
 
 =head1 CONTRIBUTORS
